Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Application ¶
type Handler ¶
type Handler struct {
// contains filtered or unexported fields
}
func NewHandler ¶
func NewHandler(app Application, storage *storage.Storage) *Handler
type MetricToolArgs ¶
type MetricsToolArgs ¶
type MockApplication ¶
MockApplication is an autogenerated mock type for the Application type
func NewMockApplication ¶
func NewMockApplication(t interface {
mock.TestingT
Cleanup(func())
}) *MockApplication
NewMockApplication creates a new instance of MockApplication. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockApplication) Cfg ¶
func (_m *MockApplication) Cfg() *config.Config
Cfg provides a mock function with no fields
Click to show internal directories.
Click to hide internal directories.